==> zio-aws-apigatewayv2_2.13-5.17.168.1-sources.jar: zio/aws/apigatewayv2/model/GetApisRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetApisRequest(
    maxResults: Optional[__string] = Optional.Absent,
    nextToken: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest = {
    import GetApisRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
      .builder()
      .optionallyWith(maxResults.map(value => value: java.lang.String))(
        _.maxResults
      )
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetApisRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetApisRequest.wrap(buildAwsValue())
}
object GetApisRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetApisRequest =
      zio.aws.apigatewayv2.model.GetApisRequest(
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def maxResults: Optional[__string]
    def nextToken: Optional[__string]
    def getMaxResults: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
  ) extends zio.aws.apigatewayv2.model.GetApisRequest.ReadOnly {
    override val maxResults: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => value: __string)
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
  ): zio.aws.apigatewayv2.model.GetApisRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.17.104.2-sources.jar: zio/aws/apigatewayv2/model/GetApisRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetApisRequest(
    maxResults: Option[__string] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest = {
    import GetApisRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
      .builder()
      .optionallyWith(
        maxResults.map(value => __string.unwrap(value): java.lang.String)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetApisRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetApisRequest.wrap(buildAwsValue())
}
object GetApisRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetApisRequest =
      zio.aws.apigatewayv2.model.GetApisRequest(
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def maxResults: Option[__string]
    def nextToken: Option[__string]
    def getMaxResults: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
  ) extends zio.aws.apigatewayv2.model.GetApisRequest.ReadOnly {
    override val maxResults: Option[__string] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.apigatewayv2.model.primitives.__string(value))
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApisRequest
  ): zio.aws.apigatewayv2.model.GetApisRequest.ReadOnly = new Wrapper(impl)
}
